/* $Id: RootW.h,v 1.4 1999/11/06 05:50:59 glgay Exp $ */
/*
 Copyright (C) 1996 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(xarm_rootw_h)
#define xarm_rootw_h

/*
 * Warning:  These classes diverge from the Motif 1.2 standard GUI and 
 * use widgets written by the author.
 */

/* ======================================================================= */
/* Include(s): */
#include <Xmext/RootW.h>
#include <Xarm/Core.h>

class RootWindowClass : public CoreClass {
 protected:
   RootWindowClass() {}
   virtual WidgetClass classPointer()  { return xmRootWindowWidgetClass; }
   virtual _XtString className()       { return (_XtString) "XmRootWindow"; }
 public:
};

typedef XarmRawWidget<RootWindowClass, false> Root;

#endif

